@@ -8,7 +8,7 @@
  ***************************************************************************/
 
 #include <KAboutData>
-
+#include <KCrash>
 #include <KUser>
 #include <QApplication>
 #include <KLocalizedString>
@@ -44,6 +44,7 @@ int main(int argc, char **argv)
 
     QCommandLineParser parser;
     KAboutData::setApplicationData(about);
+    KCrash::initialize();
     parser.addVersionOption();
     parser.addHelpOption();
     parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("demo"), i18n("Run game in demo (autoplay) mode")));
